.. python-cybox documentation master file, created by
   sphinx-quickstart on Mon Jul 29 12:05:20 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

python-cybox |release| Documentation
====================================

The python-cybox library provides an API for developing and consuming Cyber
Observable eXpression (CybOX) content. Developers can leverage the API to
create applications that create, consume, translate, or otherwise work with
CybOX content.

Contents:

.. toctree::
   :maxdepth: 2

   getting_started
   installation
   overview
   examples
   contributing


API Reference
=============

.. toctree::
   :maxdepth: 2

   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

